# Generated by the protocol buffer compiler.  DO NOT EDIT!

from google.protobuf import descriptor
from google.protobuf import message
from google.protobuf import reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)



DESCRIPTOR = descriptor.FileDescriptor(
  name='test_msg.proto',
  package='',
  serialized_pb='\n\x0etest_msg.proto\"6\n\x07TestMsg\x12\x0c\n\x04left\x18\x01 \x02(\r\x12\x0e\n\x06\x63\x65nter\x18\x02 \x02(\t\x12\r\n\x05right\x18\x03 \x02(\r')




_TESTMSG = descriptor.Descriptor(
  name='TestMsg',
  full_name='TestMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='left', full_name='TestMsg.left', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='center', full_name='TestMsg.center', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='right', full_name='TestMsg.right', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=18,
  serialized_end=72,
)

DESCRIPTOR.message_types_by_name['TestMsg'] = _TESTMSG

class TestMsg(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TESTMSG
  
  # @@protoc_insertion_point(class_scope:TestMsg)

# @@protoc_insertion_point(module_scope)
