from setuptools import setup, find_packages
import sys, os

setup(name='protobufp',
      version='0.2.3',
      description="",
      long_description="",
      classifiers=[],
      keywords='protobuf translator translation',
      author='Dustin Oprea',
      author_email='myselfasunder@gmail.com',
      url='',
      license='GPL 2',
      packages=find_packages(exclude=['test']),
      include_package_data=True,
      zip_safe=False,
      install_requires=[],
      entry_points="",
)

